yakumo.nova.v2.agent.Resource

Package yakumo :: Package nova :: Package v2 :: Module agent :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

Resource class for agents in Compute API v2

Instance Methods | [hide private]
None |
update(self, architecture=`'``__UNDEF__``'`, hypervisor=`'``__UNDEF__``'`, os=`'``__UNDEF__``'`, url=`'``__UNDEF__``'`, version=`'``__UNDEF__``'`) Update properties of an agent | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, architecture=`'``__UNDEF__``'`, hypervisor=`'``__UNDEF__``'`, os=`'``__UNDEF__``'`, url=`'``__UNDEF__``'`, version=`'``__UNDEF__``'`) | source code
Update properties of an agent Parameters: `architecture` (str) - Architecture `hypervisor` (str) - Hypervisor `os` (str) - Operating System `url` (str) - URL `version` (str) - Version Returns: None Overrides: base.Resource.update